<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="paramTemplateTypeTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>
<script>
import { fetchList, delObj } from '@/api/basic/customizeparamtemplatetype'
import { remote } from '@/api/admin/dict'
import ttable from '@/views/common/ztt-table.vue'
import TableForm from './templatetype-form'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      prelang: 'paramTemplateTypeTable',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 名称
          {
            minWidth: '120',
            prop: 'templateTypeName',
            label: '类型名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 所在页面
          {
            minWidth: '200',
            prop: 'dataType',
            label: '所在页面',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getDataTypeList()
            }
          },
          // 创建时间
          {
            minWidth: '200',
            width: '300',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      addOrUpdateVisible: false,
      dataTypeList: []
    }
  },
  components: {
    ttable,
    TableForm
  },
  created() {
    this.getParamApplyDict()
  },
  methods: {
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除类型名称为' + row.templateTypeName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row)
        })
        .then((data) => {
          if (data.data.code === 0) {
            this.$message.success('删除成功')
          } else {
            this.$message.success(data.msg)
          }
          this.getData()
        })
    },
    // 获取数据列表
    getData() {
      this.$refs.paramTemplateTypeTable.getDataList()
    },
    // 获取参数所在页面字典
    getParamApplyDict() {
      remote('routing_operation_template_data_type').then((response) => {
        if (response.data.code === 0) {
          this.dataTypeList = response.data.data
        } else {
          this.dataTypeList = []
        }
      })
    },
    getDataTypeList() {
      return this.dataTypeList
    }
  }
}
</script>
